@@ -1,4 +1,3 @@
-import logging
 import sqlite3
 from typing import Any
 
@@ -8,8 +7,6 @@ from labels.advisories.match_versions import match_vulnerable_versions
 from labels.advisories.utils import create_advisory_from_record
 from labels.model.advisories import Advisory
 
-LOGGER = logging.getLogger(__name__)
-
 
 class ImagesDatabase(BaseDatabase):
     def __init__(self) -> None:
@@ -40,7 +37,8 @@ def fetch_advisory_from_database(
             cwe_ids,
             cve_finding,
             auto_approve,
-            fixed_versions
+            fixed_versions,
+            kev_catalog
         FROM advisories
         WHERE package_manager = ? AND platform_version = ? AND package_name = ?;
         """,
@@ -98,7 +96,7 @@ def get_vulnerabilities(
     ):
         advisories_list.extend(
             [
-                match_fixed_versions(version.lower(), advisor)
+                match_fixed_versions(version.lower(), advisor, None)
                 for advisor in advisories
                 if match_vulnerable_versions(version.lower(), advisor.vulnerable_version)
             ]
@@ -120,7 +118,7 @@ def get_vulnerabilities(
     ):
         advisories_list.extend(
             [
-                match_fixed_versions(version.lower(), advisor)
+                match_fixed_versions(version.lower(), advisor, None)
                 for advisor in origin_advisories
                 if match_vulnerable_versions(version.lower(), advisor.vulnerable_version)
             ]
