@@ -19,8 +19,13 @@ import labels.enrichers.rust.complete as enrich_rust
 from labels.advisories import images as images_advisories
 from labels.advisories import roots as roots_advisories
 from labels.model.advisories import Advisory
+from labels.model.ecosystem_data.alpine import ApkDBEntry
+from labels.model.ecosystem_data.arch import AlpmDBEntry
+from labels.model.ecosystem_data.debian import DpkgDBEntry
+from labels.model.ecosystem_data.redhat import RpmDBEntry
 from labels.model.file import Location
-from labels.model.package import HealthMetadata, Language, Package, PackageType
+from labels.model.metadata import HealthMetadata
+from labels.model.package import Language, Package, PackageType
 from labels.parsers.cataloger.utils import extract_distro_info
 from labels.utils.strings import format_exception
 
@@ -81,10 +86,13 @@ ALLOWED_TYPE = dict[
 
 def update_root_advisories(package: Package) -> list[Advisory]:
     if pkg_platform := package.type.get_platform_value():
+        safe_versions = roots_advisories.get_safe_versions(pkg_platform.lower(), package.name)
+        package.safe_versions = safe_versions
         return roots_advisories.get_vulnerabilities(
             pkg_platform.lower(),
             package.name,
             package.version,
+            safe_versions,
         )
     return []
 
@@ -92,36 +100,38 @@ def update_root_advisories(package: Package) -> list[Advisory]:
 def _get_upstream_info(package: Package) -> tuple[str | None, str | None]:
     if (
         package.type == PackageType.ApkPkg
-        and package.metadata
-        and hasattr(package.metadata, "origin_package")
-        and package.metadata.origin_package
+        and isinstance(package.ecosystem_data, ApkDBEntry)
+        and package.ecosystem_data
+        and package.ecosystem_data.origin_package
     ):
-        return package.metadata.origin_package, package.version
+        return package.ecosystem_data.origin_package, package.version
 
     if (
         package.type == PackageType.DebPkg
-        and package.metadata
-        and hasattr(package.metadata, "source")
-        and hasattr(package.metadata, "source_version")
-        and package.metadata.source
+        and isinstance(package.ecosystem_data, DpkgDBEntry)
+        and package.ecosystem_data
+        and package.ecosystem_data.source
     ):
-        return package.metadata.source, package.metadata.source_version or package.version
+        return (
+            package.ecosystem_data.source,
+            package.ecosystem_data.source_version or package.version,
+        )
 
     if (
         package.type == PackageType.AlpmPkg
-        and package.metadata
-        and hasattr(package.metadata, "base_package")
-        and package.metadata.base_package
+        and isinstance(package.ecosystem_data, AlpmDBEntry)
+        and package.ecosystem_data
+        and package.ecosystem_data.base_package
     ):
-        return package.metadata.base_package, package.version
+        return package.ecosystem_data.base_package, package.version
 
     if (
         package.type == PackageType.RpmPkg
-        and package.metadata
-        and hasattr(package.metadata, "source_rpm")
-        and package.metadata.source_rpm
+        and isinstance(package.ecosystem_data, RpmDBEntry)
+        and package.ecosystem_data
+        and package.ecosystem_data.source_rpm
     ):
-        source_name = package.metadata.source_rpm.replace(".src.rpm", "").split("-")[0]
+        source_name = package.ecosystem_data.source_rpm.replace(".src.rpm", "").split("-")[0]
         return source_name, package.version
 
     return None, None
