@@ -1,11 +1,8 @@
-import logging
 from typing import NotRequired, TypedDict
 
 from labels.config.cache import dual_cache
 from labels.enrichers.api_interface import make_get
 
-LOGGER = logging.getLogger(__name__)
-
 
 class NPMPackageAuthor(TypedDict):
     email: str
