@@ -1,6 +1,7 @@
 from labels.enrichers.ruby.get import RubyGemsPackage, get_gem_package
 from labels.enrichers.utils import infer_algorithm
-from labels.model.package import Artifact, Digest, HealthMetadata, Package
+from labels.model.metadata import Artifact, Digest, HealthMetadata
+from labels.model.package import Package
 from labels.utils.licenses.validation import validate_licenses
 
 
