@@ -15,7 +15,8 @@ AdvisoryRecord = tuple[
     str | None,  # cwe_ids
     str | None,  # cve_finding
     int,  # auto_approve
-    str | None,  # fixed_versions
+    str | None,  # fixed_versions,
+    int,  # kev_catalog
 ]
 
 
@@ -27,9 +28,10 @@ class UpgradeType(str, Enum):
 
 
 class AdvisoryFixMetadata(BaseModel):
-    closest_fix_version: str | None
+    closest_fix_version: str
     upgrade_type: UpgradeType
     breaking_change: bool
+    closest_safe_version: str | None = None
 
 
 class Advisory(BaseModel):
@@ -50,3 +52,4 @@ class Advisory(BaseModel):
     cve_finding: str | None = None
     auto_approve: bool = False
     upstream_package: str | None = None
+    kev_catalog: bool = False
