@@ -1,15 +1,15 @@
 import hashlib
 import json
-from datetime import datetime
 from enum import Enum, StrEnum
-from typing import Annotated, cast
+from typing import cast
 
-from pydantic import BaseModel, StringConstraints
+from pydantic import BaseModel
 
 from labels.model.advisories import Advisory
+from labels.model.constraints import NonEmptyStr, TrimmedNonEmptyStr
+from labels.model.ecosystem_data.base import AcceptedEcosystemData
 from labels.model.file import Location
-
-NonEmptyStr = Annotated[str, StringConstraints(min_length=1)]
+from labels.model.metadata import HealthMetadata
 
 
 class Platform(StrEnum):
@@ -63,34 +63,6 @@ class Language(StrEnum):
     RUST = "rust"
     SWIFT = "swift"
 
-    def get_platform_value(self) -> str | None:
-        """Deprecate this method; use PackageType.get_platform_value() instead.
-
-        This method will be removed in the future. Please update your code to use
-        PackageType.get_platform_value().
-        """
-        # DEPRECATED: Use PackageType.get_platform_value() instead.
-        language_to_platform = {
-            Language.CPP: Platform.CONAN.value,
-            Language.DART: Platform.PUB.value,
-            Language.DOTNET: Platform.NUGET.value,
-            Language.ELIXIR: Platform.ERLANG.value,
-            Language.ERLANG: Platform.ERLANG.value,
-            Language.GO: Platform.GO.value,
-            Language.HASKELL: Platform.CABAL.value,
-            Language.JAVA: Platform.MAVEN.value,
-            Language.JAVASCRIPT: Platform.NPM.value,
-            Language.PHP: Platform.COMPOSER.value,
-            Language.PYTHON: Platform.PIP.value,
-            Language.R: Platform.CRAN.value,
-            Language.RUBY: Platform.GEM.value,
-            Language.RUST: Platform.CARGO.value,
-            Language.SWIFT: Platform.SWIFT.value,
-            Language.GITHUB_ACTIONS: Platform.GITHUB_ACTIONS.value,
-            Language.UNKNOWN_LANGUAGE: None,
-        }
-        return language_to_platform.get(self)
-
 
 class PackageType(Enum):
     UnknownPkg = "UnknownPackage"
@@ -166,37 +138,19 @@ class PackageType(Enum):
         return package_type_to_platform.get(self, Platform.UNKNOWN.value)
 
 
-class Digest(BaseModel):
-    algorithm: NonEmptyStr | None = None
-    value: NonEmptyStr | None = None
-
-
-class Artifact(BaseModel):
-    url: NonEmptyStr
-    integrity: Digest | None = None
-
-
-class HealthMetadata(BaseModel):
-    latest_version: NonEmptyStr | None = None
-    latest_version_created_at: NonEmptyStr | datetime | None = None
-    artifact: Artifact | None = None
-    authors: NonEmptyStr | None = None
-
-
 class Package(BaseModel):
     name: NonEmptyStr
-    version: Annotated[str, StringConstraints(strip_whitespace=True, min_length=1)]
+    version: TrimmedNonEmptyStr
     language: Language
     licenses: list[NonEmptyStr]
     locations: list[Location]
     type: PackageType
     advisories: list[Advisory] | None = None
-    dependencies: list["Package"] | None = None
     found_by: NonEmptyStr | None = None
     health_metadata: HealthMetadata | None = None
-    is_dev: bool = False
-    metadata: object | None = None
+    ecosystem_data: AcceptedEcosystemData | None = None
     p_url: NonEmptyStr
+    safe_versions: list[str] | None = None
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Package):
