@@ -15,7 +15,7 @@ LOGGER = logging.getLogger(__name__)
 
 
 class EnumEncoder(json.JSONEncoder):
-    def default(self, item: Any) -> Any:
+    def default(self, item: Any) -> Any:  # noqa: ANN401
         if isinstance(item, Enum):
             return item.value
         if isinstance(item, IndexedList):
@@ -56,6 +56,7 @@ def serialize_package(package: Package) -> dict[str, Any]:
         "health_metadata": package.health_metadata.model_dump()
         if package.health_metadata
         else None,
+        "safe_versions": package.safe_versions,
         "advisories": [serialize_advisory(adv) for adv in package.advisories or []],
     }
 
@@ -79,6 +80,7 @@ def serialize_advisory(advisory: Advisory) -> dict[str, Any]:
         "cve_finding": advisory.cve_finding,
         "auto_approve": advisory.auto_approve,
         "upstream_package": advisory.upstream_package,
+        "kev_catalog": advisory.kev_catalog,
     }
 
 
