@@ -79,6 +79,10 @@ FLUID_SBOM_JSON_SCHEMA = {
                             "authors": {"type": ["string", "null"]},
                         },
                     },
+                    "safe_versions": {
+                        "type": ["array", "null"],
+                        "items": {"type": "string"},
+                    },
                     "advisories": {
                         "type": "array",
                         "items": {
@@ -120,6 +124,7 @@ FLUID_SBOM_JSON_SCHEMA = {
                                             "enum": ["unknown", "major", "minor", "patch"],
                                         },
                                         "breaking_change": {"type": "boolean"},
+                                        "closest_safe_version": {"type": ["string", "null"]},
                                     },
                                     "required": [
                                         "closest_fix_version",
@@ -130,6 +135,7 @@ FLUID_SBOM_JSON_SCHEMA = {
                                 "cve_finding": {"type": ["string", "null"]},
                                 "auto_approve": {"type": "boolean"},
                                 "upstream_package": {"type": ["string", "null"]},
+                                "kev_catalog": {"type": "boolean"},
                             },
                             "required": [
                                 "cpes",
