@@ -1,31 +1,21 @@
 import logging
 import re
 
-import pefile  # type: ignore
-import semver
+import packaging.version
+import pefile  # type: ignore  # noqa: PGH003
 from packageurl import PackageURL
-from pydantic import BaseModel
 
 from labels.model.file import LocationReadCloser
 from labels.model.package import Language, Package, PackageType
 from labels.model.relationship import Relationship
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
+from labels.parsers.cataloger.utils import get_enriched_location
 from labels.utils.strings import normalize_name
 
 LOGGER = logging.getLogger(__name__)
 
 
-class DotnetPortableExecutableEntry(BaseModel):
-    assembly_version: str | None = None
-    legal_copyright: str | None = None
-    company_name: str | None = None
-    product_name: str | None = None
-    product_version: str | None = None
-    comments: str | None = None
-    internal_name: str | None = None
-
-
 # Define the regular expressions
 space_regex = re.compile(r"[\s]+")
 number_regex = re.compile(r"\d")
@@ -160,7 +150,7 @@ def extract_version(version: str) -> str:
 
 def keep_greater_semantic_version(product_version: str, file_version: str) -> str:
     try:
-        semantic_product_version = semver.VersionInfo.parse(product_version)
+        semantic_product_version = packaging.version.parse(product_version)
     except ValueError:
         LOGGER.debug(
             ("Unable to create semantic version from portable executable product version %s"),
@@ -169,7 +159,7 @@ def keep_greater_semantic_version(product_version: str, file_version: str) -> st
         return ""
 
     try:
-        semantic_file_version = semver.VersionInfo.parse(file_version)
+        semantic_file_version = packaging.version.parse(file_version)
     except ValueError:
         LOGGER.debug(
             ("Unable to create semantic version from portable executable file version %s"),
@@ -193,30 +183,51 @@ def punctuation_count(string: str) -> int:
 
 
 def find_version(version_resources: dict[str, str]) -> str:
-    product_version = extract_version(version_resources.get("ProductVersion", ""))
-    file_version = extract_version(version_resources.get("FileVersion", ""))
+    raw_product_version = version_resources.get("ProductVersion", "")
+    raw_file_version = version_resources.get("FileVersion", "")
 
-    semantic_version_compare_result = keep_greater_semantic_version(product_version, file_version)
+    product_version = extract_version(raw_product_version)
+    file_version = extract_version(raw_file_version)
 
-    if semantic_version_compare_result:
-        return semantic_version_compare_result
+    # Determine the result based on available versions
+    result = ""
 
-    product_version_detail = punctuation_count(product_version)
-    file_version_detail = punctuation_count(file_version)
+    if not product_version and not file_version:
+        result = ""
+    elif not product_version:
+        result = file_version
+    elif not file_version:
+        result = product_version
+    else:
+        # Try semantic version comparison first
+        semantic_version_compare_result = keep_greater_semantic_version(
+            product_version, file_version
+        )
+        if semantic_version_compare_result:
+            result = semantic_version_compare_result
+        else:
+            # Fallback to punctuation-based logic
+            product_version_detail = punctuation_count(product_version)
+            file_version_detail = punctuation_count(file_version)
 
-    if contains_number(product_version) and product_version_detail >= file_version_detail:
-        return product_version
+            # Determine which version to use based on punctuation count
+            if (
+                contains_number(file_version)
+                and file_version_detail > 0
+                and (
+                    not contains_number(product_version)
+                    or file_version_detail > product_version_detail
+                )
+            ):
+                result = file_version
+            elif contains_number(product_version):
+                result = product_version
+            elif contains_number(file_version):
+                result = file_version
+            else:
+                result = product_version if product_version else file_version
 
-    if contains_number(file_version) and file_version_detail > 0:
-        return file_version
-
-    if contains_number(product_version):
-        return product_version
-
-    if contains_number(file_version):
-        return file_version
-
-    return product_version
+    return result
 
 
 def build_dot_net_package(
@@ -237,15 +248,6 @@ def build_dot_net_package(
             reader.location.path(),
         )
         return None
-    metadata = DotnetPortableExecutableEntry(
-        assembly_version=version_resource.get("Assembly Version"),
-        legal_copyright=version_resource.get("LegalCopyright"),
-        comments=version_resource.get("Comments"),
-        internal_name=version_resource.get("InternalName"),
-        company_name=version_resource.get("CompanyName"),
-        product_name=version_resource.get("ProductName"),
-        product_version=version_resource.get("ProductVersion"),
-    )
 
     normalized_package_name = normalize_name(name, PackageType.DotnetPkg)
     p_url = PackageURL(
@@ -257,14 +259,15 @@ def build_dot_net_package(
         subpath="",
     ).to_string()
 
+    new_location = get_enriched_location(reader.location)
+
     return Package(
         name=normalized_package_name,
         version=version,
-        locations=[reader.location],
+        locations=[new_location],
         type=PackageType.DotnetPkg,
         language=Language.DOTNET,
         p_url=p_url,
-        metadata=metadata,
         licenses=[],
     )
 
