@@ -1,28 +1,29 @@
 import hashlib
 import logging
-import os
 import shutil
 import tempfile
+import zipfile
 from collections.abc import Callable
+from contextlib import suppress
 from io import BufferedReader
 from pathlib import Path
-from typing import TextIO, cast
+from typing import TextIO
 from zipfile import ZipInfo
 
 from pydantic import BaseModel, ConfigDict, ValidationError
 
+from labels.model.ecosystem_data.java import (
+    JavaArchive,
+    JavaManifest,
+    JavaPomProperties,
+)
 from labels.model.file import Location, LocationReadCloser
-from labels.model.package import Digest, Language, Package
-from labels.model.relationship import Relationship
+from labels.model.metadata import Digest
+from labels.model.package import Language, Package
+from labels.model.relationship import Relationship, RelationshipType
 from labels.model.release import Environment
 from labels.model.resolver import Resolver
 from labels.parsers.cataloger.java.archive_filename import ArchiveFilename, parse_filename
-from labels.parsers.cataloger.java.model import (
-    JavaArchive,
-    JavaManifest,
-    JavaPomProject,
-    JavaPomProperties,
-)
 from labels.parsers.cataloger.java.package import group_id_from_java_metadata, package_url
 from labels.parsers.cataloger.java.parse_java_manifest import (
     parse_java_manifest,
@@ -32,9 +33,15 @@ from labels.parsers.cataloger.java.parse_java_manifest import (
 )
 from labels.parsers.cataloger.java.parse_pom_properties import parse_pom_properties
 from labels.parsers.cataloger.java.parse_pom_xml import ParsedPomProject, parse_pom_xml_project
+from labels.parsers.cataloger.java.utils import get_java_package_type_from_group_id
+from labels.parsers.cataloger.utils import get_enriched_location, log_malformed_package_warning
 from labels.utils.licenses import parser
-from labels.utils.strings import format_exception
-from labels.utils.zip import contents_from_zip, new_zip_file_manifest, zip_glob_match
+from labels.utils.zip import (
+    contents_from_zip,
+    new_zip_file_manifest,
+    traverse_files_in_zip,
+    zip_glob_match,
+)
 
 LOGGER = logging.getLogger(__name__)
 
@@ -73,7 +80,7 @@ def pom_properties_by_parent(
     for file_path, file_contents in contents_of_maven_properties.items():
         if not file_contents:
             continue
-        pom_properties = parse_pom_properties(file_path, file_contents)
+        pom_properties = parse_pom_properties(file_contents)
         if not pom_properties:
             continue
         if not pom_properties.group_id or not pom_properties.version:
@@ -93,7 +100,7 @@ def pom_project_by_parent(
     project_by_parent = {}
 
     for file_path, file_contents in contents_of_maven_project.items():
-        pom_project = parse_pom_xml_project(file_path, file_contents, location)
+        pom_project = parse_pom_xml_project(file_contents, location)
         if not pom_project:
             continue
         if (
@@ -106,11 +113,18 @@ def pom_project_by_parent(
     return project_by_parent
 
 
-def artifact_id_matches_filename(artifact_id: str, filename: str) -> bool:
+def artifact_id_matches_filename(artifact_id: str, filename: str, artifacts_map: set[str]) -> bool:
     if not artifact_id or not filename:
         return False
 
-    return artifact_id.startswith(filename) or filename.startswith(artifact_id)
+    # Ensure true is returned when filename matches the artifact ID exactly,
+    # prevent random retrieval by checking if filename is in artifacts_map
+    if filename in artifacts_map:
+        return artifact_id == filename
+
+    # Use fallback check with suffix and prefix if no POM properties file
+    # matches the exact artifact name
+    return artifact_id.startswith(filename) or filename.endswith(artifact_id)
 
 
 class ArchiveParser(BaseModel):
@@ -124,19 +138,160 @@ class ArchiveParser(BaseModel):
 
     def parse(self) -> tuple[list[Package] | None, list[Relationship] | None]:
         packages = []
+        relationships = []
+
         parent_pkg = self.discover_main_package()
-        if not parent_pkg:
-            return None, None
+
+        # Process aux packages from Maven files (even if no parent package)
         aux_pkgs = self.discover_pkgs_from_all_maven_files(parent_pkg)
 
-        packages = [parent_pkg, *aux_pkgs]
+        if parent_pkg:
+            packages.append(parent_pkg)
 
-        return packages, []
+            for aux_pkg in aux_pkgs:
+                packages.append(aux_pkg)
+                relationships.append(
+                    Relationship(
+                        from_=aux_pkg.id_,
+                        to_=parent_pkg.id_,
+                        type=RelationshipType.CONTAINS_RELATIONSHIP,
+                    )
+                )
+        else:
+            # If no parent package, add aux packages without relationships
+            packages.extend(aux_pkgs)
+
+        if self.detect_nested:
+            nested_pkgs, nested_relationships = self.discover_pkgs_from_nested_archives()
+            packages.extend(nested_pkgs)
+            relationships.extend(nested_relationships)
+        else:
+            # Check for nested archives and log warning if found
+            nested_archives = zip_glob_match(
+                self.file_manifest, case_sensitive=False, patterns=("*.jar", "*.war")
+            )
+            if nested_archives:
+                LOGGER.warning(
+                    "nested archives not cataloged: %s", ", ".join(sorted(nested_archives))
+                )
+
+        if not packages:
+            LOGGER.warning("no package identified in archive: %s", self.location)
+            return None, None
+
+        return packages, relationships
+
+    def discover_pkgs_from_nested_archives(self) -> tuple[list[Package], list[Relationship]]:
+        if not self.archive_path:
+            return [], []
+
+        # Find nested Java archives
+        nested_archives = zip_glob_match(
+            self.file_manifest,
+            case_sensitive=False,
+            patterns=(
+                "*.jar",
+                "*.war",
+                "*.ear",
+                "*.par",
+                "*.sar",
+                "*.nar",
+                "*.jpi",
+                "*.hpi",
+                "*.kar",
+                "*.lpkg",
+            ),
+        )
+
+        if not nested_archives:
+            return [], []
+
+        packages = []
+        relationships = []
+
+        for archive_path in nested_archives:
+            try:
+                # Extract the nested archive
+                nested_pkgs, nested_rels = self._process_nested_archive(archive_path)
+                packages.extend(nested_pkgs)
+                relationships.extend(nested_rels)
+            except (OSError, ValueError, KeyError) as e:
+                LOGGER.warning("unable to process nested archive %s: %s", archive_path, e)
+                continue
+        return packages, relationships
+
+    def _process_nested_archive(
+        self, archive_path: str
+    ) -> tuple[list[Package], list[Relationship]]:
+        if not self.archive_path:
+            return [], []
+
+        try:
+            # Extract the nested archive to a temporary location
+            # For binary files like .jar, we need to extract as bytes, not text
+            nested_content_bytes = self._extract_binary_from_zip(self.archive_path, archive_path)
+            if not nested_content_bytes:
+                return [], []
+
+            # Create a temporary file for the nested archive
+            with tempfile.NamedTemporaryFile(
+                suffix=f"_{Path(archive_path).name}", delete=False
+            ) as temp_file:
+                temp_file.write(nested_content_bytes)
+                temp_archive_path = temp_file.name
+
+            try:
+                # Create a new location for the nested archive
+                nested_location = Location(
+                    coordinates=self.location.coordinates,
+                    access_path=f"{self.location.access_path}:{archive_path}",
+                )
+
+                # Create a new parser for the nested archive
+                nested_parser = ArchiveParser(
+                    file_manifest=new_zip_file_manifest(temp_archive_path),
+                    location=nested_location,
+                    archive_path=temp_archive_path,
+                    content_path="",  # Not needed for nested archives
+                    file_info=parse_filename(archive_path),
+                    detect_nested=True,
+                )
+
+                nested_pkgs, nested_rels = nested_parser.parse()
+
+                return nested_pkgs or [], nested_rels or []
+
+            finally:
+                with suppress(OSError):
+                    Path(temp_archive_path).unlink()
+
+        except (OSError, ValueError, KeyError) as e:
+            LOGGER.debug("error processing nested archive %s: %s", archive_path, e)
+            return [], []
+
+    def _extract_binary_from_zip(self, archive_path: str, file_path: str) -> bytes | None:
+        """Extract a binary file from a zip archive using existing zip utilities."""
+        try:
+            result = None
+
+            def visitor(file: zipfile.ZipInfo) -> None:
+                nonlocal result
+                if not file.is_dir():
+                    with (
+                        zipfile.ZipFile(archive_path, "r") as zip_reader,
+                        zip_reader.open(file) as file_data,
+                    ):
+                        result = file_data.read()
+
+            traverse_files_in_zip(archive_path, visitor, file_path)
+        except (OSError, ValueError, KeyError) as e:
+            LOGGER.debug("Error extracting binary file %s: %s", file_path, e)
+            return None
+        return result
 
     def discover_pkgs_from_all_maven_files(self, parent_pkg: Package | None) -> list[Package]:
         if not parent_pkg or not self.archive_path:
             return []
-
         pkgs: list[Package] = []
 
         properties = pom_properties_by_parent(
@@ -153,10 +308,7 @@ class ArchiveParser(BaseModel):
         for parent_path, properties_obj in properties.items():
             pom_project: ParsedPomProject | None = projects.get(parent_path, None)
             if pkg_from_pom := new_package_from_maven_data(
-                properties_obj,
-                pom_project,
-                parent_pkg,
-                self.location,
+                properties_obj, pom_project, self.location
             ):
                 pkgs.append(pkg_from_pom)
         return pkgs
@@ -167,45 +319,54 @@ class ArchiveParser(BaseModel):
             case_sensitive=False,
             patterns=("/META-INF/MANIFEST.MF",),
         )
-        if not manifest_matches or not self.archive_path:
+
+        # Early validation checks
+        if len(manifest_matches) != 1:
+            if len(manifest_matches) > 1:
+                LOGGER.error("found multiple manifests in the jar: %s", manifest_matches)
+            else:
+                LOGGER.warning("no manifests found in the jar")
             return None
-        contents = contents_from_zip(self.archive_path, *manifest_matches)
-        if not contents:
+
+        if not self.archive_path or not (
+            contents := contents_from_zip(self.archive_path, *manifest_matches)
+        ):
             return None
 
         manifest_contents = contents[manifest_matches[0]]
         manifest = parse_java_manifest(manifest_contents)
-        licenses_, name, version, group_id = self.parse_licenses(manifest)
-        metadata = JavaArchive(
-            virtual_path=self.location.path(),
-            manifest=manifest,
-            archive_digests=get_digests_from_archive(self.archive_path),
-        )
 
+        if not manifest or (manifest.main and "Weave-Classes" in manifest.main):
+            if not manifest:
+                LOGGER.warning("failed to parse java manifest: %s", self.location)  # type: ignore[unreachable]
+            else:
+                LOGGER.warning(
+                    "excluding archive due to Weave-Classes manifest entry: %s", self.location
+                )
+            return None
+
+        licenses_, name, version, group_id = self.parse_licenses(manifest)
         if not name or not version:
             return None
 
+        ecosystem_data = JavaArchive(manifest=manifest)
+
+        new_location = get_enriched_location(self.location)
+
         try:
+            authoritative_group_id = group_id_from_java_metadata(name, ecosystem_data) or group_id
             return Package(
-                name=f"{group_id}:{name}",
+                name=f"{authoritative_group_id}:{name}",
                 version=version,
                 licenses=licenses_,
-                locations=[self.location],
+                locations=[new_location],
                 type=self.file_info.pkg_type(),
                 language=Language.JAVA,
-                metadata=metadata,
-                p_url=package_url(name, version, metadata),
+                ecosystem_data=ecosystem_data,
+                p_url=package_url(name, version, ecosystem_data),
             )
         except ValidationError as ex:
-            LOGGER.warning(
-                "Malformed package. Required fields are missing or data types are incorrect.",
-                extra={
-                    "extra": {
-                        "exception": format_exception(str(ex)),
-                        "location": self.location.path(),
-                    },
-                },
-            )
+            log_malformed_package_warning(new_location, ex)
             return None
 
     def get_license_from_file_in_archive(self) -> list[str]:
@@ -257,6 +418,7 @@ class ArchiveParser(BaseModel):
             file_licenses = self.get_license_from_file_in_archive()
             if file_licenses:
                 licenses_.extend(file_licenses)
+
         return licenses_, name, version, group_id
 
     def extract_properties_and_projects(
@@ -286,10 +448,15 @@ class ArchiveParser(BaseModel):
         properties: dict[str, JavaPomProperties],
         projects: dict[str, ParsedPomProject],
     ) -> tuple[JavaPomProperties | None, ParsedPomProject | None]:
+        # Create artifacts map for exact matching
+        artifacts_map = {props.artifact_id for props in properties.values() if props.artifact_id}
+
         for parent_path, properties_obj in properties.items():
             if (
                 properties_obj.artifact_id
-                and artifact_id_matches_filename(properties_obj.artifact_id, self.file_info.name)
+                and artifact_id_matches_filename(
+                    properties_obj.artifact_id, self.file_info.name, artifacts_map
+                )
                 and (proj := projects.get(parent_path))
             ):
                 return properties_obj, proj
@@ -337,13 +504,13 @@ def save_archive_to_tmp(
     def cleanup_fn() -> None:
         shutil.rmtree(temp_dir)
 
-    content_dir = os.path.join(temp_dir, "contents")
-    Path(content_dir).mkdir()
+    content_dir = Path(temp_dir, "contents")
+    content_dir.mkdir()
 
-    archive_path = os.path.join(temp_dir, f"archive-{name}")
+    archive_path = Path(temp_dir, f"archive-{name}")
     shutil.copy(archive_virtual_path, archive_path)
 
-    return content_dir, archive_path, cleanup_fn
+    return str(content_dir), str(archive_path), cleanup_fn
 
 
 def new_java_archive_parser(
@@ -385,7 +552,6 @@ def parse_java_archive(
     parser, _file_cleanup_fn = new_java_archive_parser(reader, detect_nested=True)
     if parser is None:
         return [], []
-
     pkgs, relations = parser.parse()
     return pkgs or [], relations or []
 
@@ -393,7 +559,6 @@ def parse_java_archive(
 def new_package_from_maven_data(
     pom_properties: JavaPomProperties,
     _parsed_pom_project: ParsedPomProject | None,
-    parent_pkg: Package,
     location: Location,
 ) -> Package | None:
     artifact_id = pom_properties.artifact_id
@@ -401,46 +566,27 @@ def new_package_from_maven_data(
 
     if not artifact_id or not version:
         return None
-    full_name = f"{pom_properties.group_id}:{artifact_id}"
-    v_path_suffix = ""
 
-    parent_metadata: JavaArchive = cast("JavaArchive", parent_pkg.metadata)
-    group_id = group_id_from_java_metadata(parent_pkg.name, parent_metadata)
-    parent_key = f"{group_id}:{parent_pkg.name}:{parent_pkg.version}"
-    pom_project_key = f"{full_name}:{version}"
+    ecosystem_data = JavaArchive(pom_properties=pom_properties)
 
-    if parent_key != pom_project_key:
-        v_path_suffix += f":{full_name}"
-
-    virtual_path = f"{location.path()}{v_path_suffix}"
-    pkg_pom_project: JavaPomProject | None = None
-
-    metadata = JavaArchive(
-        virtual_path=virtual_path,
-        pom_properties=pom_properties,
-        pom_project=pkg_pom_project,
-        parent=parent_pkg,
+    authoritative_group_id = (
+        group_id_from_java_metadata(artifact_id, ecosystem_data) or pom_properties.group_id
     )
+    authoritative_full_name = f"{authoritative_group_id}:{artifact_id}"
+
+    new_location = get_enriched_location(location)
 
     try:
         return Package(
-            name=full_name,
+            name=authoritative_full_name,
             version=version,
             licenses=[],
-            locations=[location],
-            type=pom_properties.pkg_type_indicated(),
+            locations=[new_location],
+            type=get_java_package_type_from_group_id(pom_properties.group_id),
             language=Language.JAVA,
-            metadata=metadata,
-            p_url=package_url(artifact_id, version, metadata),
+            ecosystem_data=ecosystem_data,
+            p_url=package_url(artifact_id, version, ecosystem_data),
         )
     except ValidationError as ex:
-        LOGGER.warning(
-            "Malformed package. Required fields are missing or data types are incorrect.",
-            extra={
-                "extra": {
-                    "exception": format_exception(str(ex)),
-                    "location": location.path(),
-                },
-            },
-        )
+        log_malformed_package_warning(new_location, ex)
         return None
