@@ -1,14 +1,12 @@
 import logging
 import re
 
-from labels.parsers.cataloger.java.model import (
-    JavaPomProperties,
-)
+from labels.model.ecosystem_data.java import JavaPomProperties
 
 LOGGER = logging.getLogger(__name__)
 
 
-def parse_pom_properties(path: str, file_content: str) -> JavaPomProperties | None:
+def parse_pom_properties(file_content: str) -> JavaPomProperties | None:
     prop_map = {}
 
     for raw_line in file_content.splitlines():
@@ -28,12 +26,10 @@ def parse_pom_properties(path: str, file_content: str) -> JavaPomProperties | No
         prop_map[key] = value
 
     # Convert the dictionary to a JavaPomProperties object
-    props = JavaPomProperties(path=path)
+    converted_props = {}
     for raw_key, value in prop_map.items():
         key = re.sub(r"(?<!^)(?=[A-Z])", "_", raw_key).lower()
-        if hasattr(props, key):
-            setattr(props, key, value)
-        else:
-            props.extra[key] = value
+        if key in set(JavaPomProperties.__annotations__.keys()):
+            converted_props[key] = value
 
-    return props
+    return JavaPomProperties(**converted_props)
