@@ -1,10 +1,6 @@
-from pydantic import (
-    BaseModel,
-)
+from pydantic import BaseModel
 
-from labels.model.package import (
-    Digest,
-)
+from labels.model.metadata import Digest
 
 
 class NpmPackage(BaseModel):
